@@ -18,7 +18,6 @@
 
 #include <Python.h>
 #include <stdbool.h>
-
 #include "types.h"
 
 #define TRACE() printf("%s:%d\n",__FILE__,__LINE__)
@@ -101,6 +100,41 @@ PyObject * AerospikeClient_Put(AerospikeClient * self, PyObject * args, PyObject
  */
 PyObject * AerospikeClient_Remove(AerospikeClient * self, PyObject * args, PyObject * kwds);
 
+/**
+ * Append a record to the database.
+ *
+ *		client.append((x,y,z))
+ *
+ */
+PyObject * AerospikeClient_Append(AerospikeClient * self, PyObject * args, PyObject * kwds);
+/**
+ * Prepend a record to the database.
+ *
+ *		client.prepend((x,y,z))
+ *
+ */
+PyObject * AerospikeClient_Prepend(AerospikeClient * self, PyObject * args, PyObject * kwds);
+/**
+ * Increment bin value of a record to the database.
+ *
+ *		client.increment((x,y,z))
+ *
+ */
+PyObject * AerospikeClient_Increment(AerospikeClient * self, PyObject * args, PyObject * kwds);
+/**
+ * Touch a record in the database.
+ *
+ *		client.touch((x,y,z))
+ *
+ */
+PyObject * AerospikeClient_Touch(AerospikeClient * self, PyObject * args, PyObject * kwds);
+/**
+ * Performs operate operations
+ *
+ *		client.operate((x,y,z))
+ *
+ */
+PyObject * AerospikeClient_Operate(AerospikeClient * self, PyObject * args, PyObject * kwds);
 
 /*******************************************************************************
  * INTENRAL (SHARED) OPERATIONS, FOR COMPATIBILITY W/ OLD API
@@ -127,7 +161,6 @@ PyObject * AerospikeClient_Remove_Invoke(
 	AerospikeClient * self,
 	PyObject * py_key, long generation, PyObject * py_policy);
 
-
 /*******************************************************************************
  * KEY OPERATIONS (DEPRECATED)
  ******************************************************************************/
@@ -217,7 +250,7 @@ AerospikeQuery * AerospikeClient_Query(AerospikeClient * self, PyObject * args,
  *				print "{0} - ERR: {1}".format(record,err)
  *
  */
-PyObject * AerospikeClient_InfoMany(AerospikeClient * self, PyObject * args, PyObject * kwds);
+PyObject * AerospikeClient_InfoNode(AerospikeClient * self, PyObject * args, PyObject * kwds);
 
 
 /*******************************************************************************
@@ -275,6 +308,13 @@ PyObject * AerospikeClient_Index_String_Create(AerospikeClient * self, PyObject
  */
 PyObject * AerospikeClient_Index_Remove(AerospikeClient * self, PyObject *args, PyObject * kwds);
 
+#define OPERATOR_PREPEND 4
+#define OPERATOR_APPEND  5
+#define OPERATOR_TOUCH   8
+#define OPERATOR_INCR    2
+#define OPERATOR_READ    1
+#define OPERATOR_WRITE   0
+
 /**
  * Get records in a batch
  *
@@ -290,3 +330,18 @@ PyObject * AerospikeClient_Get_Many(AerospikeClient * self, PyObject *args, PyOb
  *
  */
 PyObject * AerospikeClient_Exists_Many(AerospikeClient * self, PyObject *args, PyObject * kwds);
+/**
+* Perform info operation on the database.
+*
+* client.info((x,y,z))
+*
+*/
+PyObject * AerospikeClient_Info(AerospikeClient * self, PyObject * args, PyObject * kwds);
+
+/**
+* Perforrm get nodes operation on the database.
+*
+* client.get_nodes((x,y,z))
+*
+*/
+PyObject * AerospikeClient_GetNodes(AerospikeClient * self, PyObject * args, PyObject * kwds);
