@@ -18,4 +18,4 @@
 
 #include <Python.h>
 
-PyObject * AerospikePredicates_New();
\ No newline at end of file
+PyObject * AerospikePredicates_New(void);
