@@ -62,6 +62,18 @@ PyMODINIT_FUNC initaerospike(void)
 	Py_INCREF(scan);
 	PyModule_AddObject(aerospike, "Scan", (PyObject *) scan);
 
+    PyModule_AddIntMacro(aerospike, OPERATOR_PREPEND);
+    PyModule_AddIntMacro(aerospike, OPERATOR_APPEND);
+    PyModule_AddIntMacro(aerospike, OPERATOR_READ);
+    PyModule_AddIntMacro(aerospike, OPERATOR_WRITE);
+    PyModule_AddIntMacro(aerospike, OPERATOR_TOUCH);
+    PyModule_AddIntMacro(aerospike, OPERATOR_INCR);
+
+    /*
+     * Add constants to module.
+     */
+    declare_policy_constants(aerospike);
+
 	PyObject * predicates = AerospikePredicates_New();
 	Py_INCREF(predicates);
 	PyModule_AddObject(aerospike, "predicates", predicates);
