@@ -28,8 +28,8 @@
 #include "policy.h"
 
 PyObject * AerospikeClient_Apply_Invoke(
-	AerospikeClient * self, 
-	PyObject * py_key, PyObject * py_module, PyObject * py_function, 
+	AerospikeClient * self,
+	PyObject * py_key, PyObject * py_module, PyObject * py_function,
 	PyObject * py_arglist, PyObject * py_policy)
 {
 	// Python Return Value
@@ -37,23 +37,28 @@ PyObject * AerospikeClient_Apply_Invoke(
 
 	// Aerospike Client Arguments
 	as_error err;
-	as_policy_apply policy;
-	as_policy_apply * policy_p = NULL;
+	as_policy_apply apply_policy;
+	as_policy_apply * apply_policy_p = NULL;
 	as_key key;
 	char * module = NULL;
 	char * function = NULL;
 	as_list * arglist = NULL;
 	as_val * result = NULL;
-	
+
 	// Initialize error
 	as_error_init(&err);
 
+	if (!self || !self->as) {
+		as_error_update(&err, AEROSPIKE_ERR_PARAM, "Invalid aerospike object");
+		goto CLEANUP;
+	}
+
 	// Convert python key object to as_key
 	pyobject_to_key(&err, py_key, &key);
 	if ( err.code != AEROSPIKE_OK ) {
 		goto CLEANUP;
 	}
-	
+
 	// Convert python list to as_list
 	pyobject_to_list(&err, py_arglist, &arglist);
 	if ( err.code != AEROSPIKE_OK ) {
@@ -61,7 +66,7 @@ PyObject * AerospikeClient_Apply_Invoke(
 	}
 
 	// Convert python policy object to as_policy_apply
-	pyobject_to_policy_apply(&err, py_policy, &policy, &policy_p);
+	pyobject_to_policy_apply(&err, py_policy, &apply_policy, &apply_policy_p);
 	if ( err.code != AEROSPIKE_OK ) {
 		goto CLEANUP;
 	}
@@ -70,21 +75,22 @@ PyObject * AerospikeClient_Apply_Invoke(
 	function = PyString_AsString(py_function);
 
 	// Invoke operation
-	aerospike_key_apply(self->as, &err, policy_p, &key, module, function, arglist, &result);
+	aerospike_key_apply(self->as, &err, apply_policy_p, &key, module, function, arglist, &result);
 
 	if ( err.code == AEROSPIKE_OK ) {
 		val_to_pyobject(&err, result, &py_result);
 	}
 
 CLEANUP:
-	
+
 	as_list_destroy(arglist);
 	as_val_destroy(result);
-	
+
 	if ( err.code != AEROSPIKE_OK ) {
 		PyObject * py_err = NULL;
 		error_to_pyobject(&err, &py_err);
 		PyErr_SetObject(PyExc_Exception, py_err);
+		Py_DECREF(py_err);
 		return NULL;
 	}
 
@@ -105,12 +111,12 @@ PyObject * AerospikeClient_Apply(AerospikeClient * self, PyObject * args, PyObje
 	static char * kwlist[] = {"key", "module", "function", "args", "policy", NULL};
 
 	// Python Function Argument Parsing
-	if ( PyArg_ParseTupleAndKeywords(args, kwds, "OOOO|O:apply", kwlist, 
+	if ( PyArg_ParseTupleAndKeywords(args, kwds, "OOOO|O:apply", kwlist,
 			&py_key, &py_module, &py_function, &py_arglist, &py_policy) == false ) {
 		return NULL;
 	}
 
 	// Invoke Operation
-	return AerospikeClient_Apply_Invoke(self, py_key, py_module, py_function, 
+	return AerospikeClient_Apply_Invoke(self, py_key, py_module, py_function,
 		py_arglist, py_policy);
 }
