@@ -90,6 +90,21 @@ static PyMethodDef AerospikeClient_Type_Methods[] = {
 	{"apply",
 		(PyCFunction) AerospikeClient_Apply, METH_VARARGS | METH_KEYWORDS,
 		"Apply a UDF on a record in the database."},
+    {"append",
+        (PyCFunction) AerospikeClient_Append, METH_VARARGS | METH_KEYWORDS,
+        "Appends a string to the string value in a bin"},
+	{"prepend",
+		(PyCFunction) AerospikeClient_Prepend, METH_VARARGS | METH_KEYWORDS,
+		"Prepend a record to the database"},
+	{"touch",
+		(PyCFunction) AerospikeClient_Touch, METH_VARARGS | METH_KEYWORDS,
+		"Touch a record in the database"},
+	{"increment",
+		(PyCFunction) AerospikeClient_Increment, METH_VARARGS | METH_KEYWORDS,
+		"Increments a numeric value in a bin"},
+	{"operate",
+		(PyCFunction) AerospikeClient_Operate, METH_VARARGS | METH_KEYWORDS,
+		"Performs operate operation"},
 
 	// Deprecated key-based API
 
@@ -110,10 +125,15 @@ static PyMethodDef AerospikeClient_Type_Methods[] = {
 		"Create a new Scan object for performing scans."},
 
 	// INFO OPERATIONS
-
-	{"info_many",
-		(PyCFunction) AerospikeClient_InfoMany, METH_VARARGS | METH_KEYWORDS,
+	{"info",
+		(PyCFunction) AerospikeClient_Info, METH_VARARGS | METH_KEYWORDS,
 		"Send an info request to the cluster."},
+	{"info_node",
+		(PyCFunction) AerospikeClient_InfoNode, METH_VARARGS | METH_KEYWORDS,
+		"Send an info request to the cluster."},
+	{"get_nodes",
+		(PyCFunction) AerospikeClient_GetNodes, METH_VARARGS | METH_KEYWORDS,
+		"Gets information about the nodes of the cluster."},
 
 	// UDF OPERATIONS
 
@@ -340,7 +360,6 @@ PyTypeObject * AerospikeClient_Ready()
 AerospikeClient * AerospikeClient_New(PyObject * parent, PyObject * args, PyObject * kwds)
 {
 	AerospikeClient * self = (AerospikeClient *) AerospikeClient_Type.tp_new(&AerospikeClient_Type, args, kwds);
-
 	if ( AerospikeClient_Type.tp_init((PyObject *) self, args, kwds) == 0 ){
 		// Initialize connection flag
 		return self;
@@ -355,6 +374,4 @@ AerospikeClient * AerospikeClient_New(PyObject * parent, PyObject * args, PyObje
 		Py_DECREF(py_err);
 		return NULL;
 	}
-	/*AerospikeClient_Type.tp_init((PyObject *) self, args, kwds);
-	  return self;*/
 }
