@@ -33,7 +33,7 @@ static PyObject * AerospikePredicates_Equals(PyObject * self, PyObject * args)
 
 	if ( PyArg_ParseTuple(args, "OO:equals", 
 			&py_bin, &py_val) == false ) {
-		return NULL;
+		goto exit;
 	}
 
 	if ( PyInt_Check(py_val) || PyLong_Check(py_val) ) {
@@ -43,16 +43,9 @@ static PyObject * AerospikePredicates_Equals(PyObject * self, PyObject * args)
 		return Py_BuildValue("iOO", AS_PREDICATE_STRING_EQUAL, py_bin, py_val);
 	}
 
-	// Return an error
-	as_error err;
-	as_error_update(&err, AEROSPIKE_ERR_PARAM, "equals() expects either an integer or string value.");
-
-	PyObject * py_err = NULL;
-	error_to_pyobject(&err, &py_err);
-	PyErr_SetObject(PyExc_Exception, py_err);
-
-	return NULL;
-
+exit:
+	Py_INCREF(Py_None);
+	return Py_None;
 }
 
 static PyObject * AerospikePredicates_Between(PyObject * self, PyObject * args)
@@ -63,22 +56,16 @@ static PyObject * AerospikePredicates_Between(PyObject * self, PyObject * args)
 
 	if ( PyArg_ParseTuple(args, "OOO:between", 
 			&py_bin, &py_min, &py_max) == false ) {
-		return NULL;
+		goto exit;
 	}
 
 	if ( (PyInt_Check(py_min) || PyLong_Check(py_min)) && (PyInt_Check(py_max) || PyLong_Check(py_max)) ) {
 		return Py_BuildValue("iOOO", AS_PREDICATE_INTEGER_RANGE, py_bin, py_min, py_max);
 	}
 
-	// Return an error
-	as_error err;
-	as_error_update(&err, AEROSPIKE_ERR_PARAM, "between() expects two integer values.");
-
-	PyObject * py_err = NULL;
-	error_to_pyobject(&err, &py_err);
-	PyErr_SetObject(PyExc_Exception, py_err);
-
-	return NULL;
+exit:
+	Py_INCREF(Py_None);
+	return Py_None;
 }
 
 static PyMethodDef AerospikePredicates_Methods[] = {
@@ -88,7 +75,7 @@ static PyMethodDef AerospikePredicates_Methods[] = {
 };
 
 
-PyObject * AerospikePredicates_New()
+PyObject * AerospikePredicates_New(void)
 {
 	PyObject * module = Py_InitModule3("aerospike.predicates", AerospikePredicates_Methods, "Query Predicates");
 	return module;
