@@ -35,10 +35,10 @@ typedef struct {
 
 static bool each_result(const as_val * val, void * udata)
 {
-	bool rval = TRUE;
+	bool rval = true;
 
 	if ( !val ) {
-		return FALSE;
+		return false;
 	}
 
 	// Extract callback user-data
@@ -47,7 +47,7 @@ static bool each_result(const as_val * val, void * udata)
 	PyObject * py_callback = data->callback;
 
 	// Python Function Arguments and Result Value
-	PyObject * py_arglist = NULL; 
+	PyObject * py_arglist = NULL;
 	PyObject * py_result = NULL;
 	PyObject * py_return = NULL;
 
@@ -72,20 +72,23 @@ static bool each_result(const as_val * val, void * udata)
 	if ( py_return == NULL ) {
 		// an exception was raised, handle it (someday)
 		// for now, we bail from the loop
-		rval = FALSE;
+		as_error_update(err, AEROSPIKE_ERR_PARAM, "Callback function contains an error");
+		rval = false;
 	}
 	else if (  PyBool_Check(py_return) ) {
 		if ( Py_False == py_return ) {
-			rval = FALSE;
+			rval = false;
 		}
 		else {
-			rval = TRUE;
+			rval = true;
 		}
+		Py_DECREF(py_return);
 	}
 	else {
-		rval = TRUE;
+		rval = true;
+		Py_DECREF(py_return);
 	}
-	
+
 	// Release Python State
 	PyGILState_Release(gstate);
 
@@ -97,6 +100,8 @@ PyObject * AerospikeScan_Foreach(AerospikeScan * self, PyObject * args, PyObject
 	// Python Function Arguments
 	PyObject * py_callback = NULL;
 	PyObject * py_policy = NULL;
+	as_policy_scan scan_policy;
+	as_policy_scan * scan_policy_p = NULL;
 
 	// Python Function Keyword Arguments
 	static char * kwlist[] = {"callback", "policy", NULL};
@@ -108,14 +113,17 @@ PyObject * AerospikeScan_Foreach(AerospikeScan * self, PyObject * args, PyObject
 
 	// Aerospike Client Arguments
 	as_error err;
-	as_policy_scan policy;
-	as_policy_scan * policy_p = NULL;
 
 	// Initialize error
 	as_error_init(&err);
 
+	if (!self || !self->client->as) {
+		as_error_update(&err, AEROSPIKE_ERR_PARAM, "Invalid aerospike object");
+		goto CLEANUP;
+	}
+
 	// Convert python policy object to as_policy_exists
-	pyobject_to_policy_scan(&err, py_policy, &policy, &policy_p);
+	pyobject_to_policy_scan(&err, py_policy, &scan_policy, &scan_policy_p);
 	if ( err.code != AEROSPIKE_OK ) {
 		goto CLEANUP;
 	}
@@ -124,25 +132,29 @@ PyObject * AerospikeScan_Foreach(AerospikeScan * self, PyObject * args, PyObject
 	LocalData data;
 	data.callback = py_callback;
 	as_error_init(&data.error);
-	
+
 	// We are spawning multiple threads
 	PyThreadState * _save = PyEval_SaveThread();
 
 	// Invoke operation
-	aerospike_scan_foreach(self->client->as, &err, policy_p, &self->scan, each_result, &data);
+	aerospike_scan_foreach(self->client->as, &err, scan_policy_p, &self->scan, each_result, &data);
 
 	// We are done using multiple threads
 	PyEval_RestoreThread(_save);
-	
+	if (data.error.code != AEROSPIKE_OK) {
+		goto CLEANUP;
+	}
+
 CLEANUP:
 
 	if ( err.code != AEROSPIKE_OK ) {
 		PyObject * py_err = NULL;
 		error_to_pyobject(&err, &py_err);
 		PyErr_SetObject(PyExc_Exception, py_err);
+		Py_DECREF(py_err);
 		return NULL;
 	}
-	
+
 	Py_INCREF(Py_None);
 	return Py_None;
-}
\ No newline at end of file
+}
